@@ -13,5 +13,4 @@ except PackageNotFoundError:  # pragma: no cover
     __version__ = "unknown"
 
 from layer_to_layer_pytorch.l2l import Layer2Layer
-from layer_to_layer_pytorch.loss import L2LLoss
-from layer_to_layer_pytorch.types import Device, LossFn, TensorOrTensorArray
+from layer_to_layer_pytorch.types import Criterion, Device
